====================
cmsplugin-nivoslider
====================

Beautiful image and content slider plugin.
Shows the widely used jQuery Nivo slider plugin from
http://nivo.dev7studios.com/.

Features:
  - Easily upload dozens of images thanks to django-filer;
  - HTML description for each image;
  - Four default nivo slider theme choices;
  - User selection of nivo parameters: themes, animation, manual advance,
    thumbnails, etc;
  - Auto-discovering of custom nivo themes on static dirs.

Requires:
  - `django-CMS <https://github.com/divio/django-cms>`_
    (tested with 2.3)
  - `django-filer <https://github.com/stefanfoulis/django-filer>`_
    (tested with 0.9a1)


Installation
============

#. `pip install cmsplugin_nivoslider`
#. Add `'cmsplugin_nivoslider'` to `INSTALLED_APPS`
#. Add ``'cmsplugin_nivoslider.thumbnail_processors.pad_image',``
   to your ``THUMBNAIL_PROCESSORS`` (before ``autocrop``)
#. Run `./manage.py syncdb` (or `./manage.py migrate cmsplugin_nivoslider`
   if you are using South)

You need to have correctly configured staticfiles for autodiscovering and using themes.


Upgrading to 0.4
================

On version 0.4, we have dropped the custom image albums in behalf of django-filer Folders.
So if you are upgrading from a previous version, you will have to upload again your images to a filer folder.


Using a custom or downloaded theme
==================================

When reloading your Django app, the plugin will search for themes on the following
static dir: `nivo/themes/`.

So all you need to do is putting your theme plugin on `static/nivo/themes/pluginname`
dir of some app of your Django project. 

So after collectstatic, theme will be available under the directory:
`STATIC_ROOT/nivo/themes/pluginname`
And will be found by cmsplugin_nivoslider.

:Authors:
  - Bernardo Cabezas serra - bcabezas@apsl.net - http://www.apsl.net/
  - Bertrand Bordage - bordage.bertrand@gmail.com

:Initial version date:
  2012/03/14
